@@ -1,7 +1,7 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
 ;;; Copyright © 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
-;;; Copyright © 2014, 2018, 2020, 2021, 2022, 2023 Rutger van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2014, 2018, 2020, 2021, 2022, 2023, 2025 Rutger van Beusekom <rutger@dezyne.org>
 ;;; Copyright © 2017, 2018, 2019, 2020 Rob Wieringa <rma.wieringa@gmail.com>
 ;;; Copyright © 2017, 2018, 2020 Johri van Eerd <vaneerd.johri@gmail.com>
 ;;; Copyright © 2018 Filip Toman <filip.toman@verum.com>
@@ -36,7 +36,7 @@
 
   #:use-module (dzn ast accessor)
   #:use-module (dzn ast equal)
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
   #:use-module (dzn ast util)
   #:use-module (dzn misc)
 
@@ -213,21 +213,24 @@
   (let ((root (or (as context <root>) (ast:parent context <root>))))
     ((ast:perfect-funcq search-import-unmemoized) root scope name context)))
 
-(define (search-unmemoized root
-                           scope name context)
-  (let* ((global? (and (pair? scope) (equal? "/" (car scope))))
-         (scope (if (not (and global? (is-a? context <root>))) scope
-                    (filter (match-lambda ("/" #f) (o o)) scope)))
-         (global? (and (pair? scope) (equal? "/" (car scope))))
-         (target (if (null? scope) name (car scope)))
-         (found (filter (cute ast:name-equal? <> target)
-                        (ast:declaration* context))))
-    (and (pair? found)
-         (match scope
-           (()
-            (car found))
-           ((scope tail ...)
-            (any (cute search tail name <>) found))))))
+(define (search-unmemoized root scope name context)
+  (if (and (null? scope) (string-contains name "."))
+      (let ((names (string-split name #\.)))
+        (search-unmemoized root (drop-right names 1) (last names) context))
+      (let* ((global? (and (pair? scope) (equal? "/" (car scope))))
+             (scope (if (not (and global? (is-a? context <root>))) scope
+                        (filter (match-lambda ("/" #f) (o o)) scope)))
+             (global? (and (pair? scope) (equal? "/" (car scope))))
+             (target (if (null? scope) name (car scope)))
+             (foo (ast:declaration* context))
+             (found (filter (cute ast:name-equal? <> target)
+                            (ast:declaration* context))))
+        (and (pair? found)
+             (match scope
+               (()
+                (car found))
+               ((scope tail ...)
+                (any (cute search tail name <>) found)))))))
 
 (define (search scope name context)
   (let ((root (or (as context <root>) (ast:parent context <root>))))
@@ -308,7 +311,7 @@ null) and return its CONTEXT."
       (and (is-a? (.parent o) <compound>)
            (ast:lookup-variable (.parent o) name (ast:statement-prefix o)))
       (ast:lookup-variable (.parent o) name statements)))
-    (($ <function>)
+    ((? (is? <function>))
      (or (find name? ((compose ast:formal* .signature) o))
          (ast:lookup-variable (.parent o) name statements)))
     (($ <formal>)
