@@ -1,8 +1,8 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2020, 2021 Rutger van Beusekom <rutger@dezyne.org>
-;;; Copyright © 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
-;;; Copyright © 2021 Paul Hoogendijk <paul@dezyne.org>
+;;; Copyright © 2020, 2021, 2025 Rutger (regtur) van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2020, 2021, 2022, 2023, 2025 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2021, 2025 Paul Hoogendijk <paul@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -115,12 +115,14 @@
 
             tree:add-file-name
             tree:collect
+            tree:filter
             tree:debug-context
             tree:direction
             tree:dotted-name
             tree:file-name
             tree:location
             tree:name
+            tree:normalize
             tree:offset
             tree:scope+name
 
@@ -201,9 +203,10 @@ procedure)."
   (and (match predicate
          ((? symbol?)
           (and (pair? o)
-               (and (eq? predicate (car o)) o)))
+               (eq? predicate (car o))))
          ((? procedure? predicate)
-          (and (predicate o) o)))))
+          (predicate o)))
+       o))
 
 (define (is? predicate)
   "Return a predicate that tests for PREDICATE."
@@ -440,9 +443,13 @@ procedure)."
     ((? (is? 'trigger)) (slot o 'trigger-formals))))
 
 (define (.type-name o)
-  (assert-type o 'compound-name 'enum-literal 'event 'formal 'function 'instance 'port 'variable)
+  (assert-type o 'compound-name 'enum-literal 'event 'formal 'function 'instance 'port 'provides 'requires 'variable)
   (match o
-    ((? (is? 'port))    ;; Hmm: .compound-name??
+    ((? (is? 'port))
+     (or (and=> (slot o 'provides) .type-name)
+         (and=> (slot o 'requires) .type-name)
+         (slot o 'compound-name)))
+    ((or (? (is? 'provides)) (? (is? 'requires)))
      (slot o 'compound-name))
     ((? (is? 'instance))
      (slot o 'compound-name))
@@ -538,6 +545,7 @@ procedure)."
      event-name
      events
      expression
+     expression-function
      external
      field-test
      fields
@@ -552,6 +560,7 @@ procedure)."
      illegal-trigger
      illegal-triggers
      injected
+     invariant
      import
      instance
      instances-and-bindings
@@ -593,7 +602,7 @@ procedure)."
      o)
     (((? symbol?) slot ...)
      (format (current-error-port)
-             "programming-warning: tree?: missing-type: ~a\n" o))
+             "programming-warning: tree?: missing-type: ~s\n" o))
     (_
      #f)))
 
@@ -780,24 +789,17 @@ procedure)."
 
 (define (tree:list-model* tree)
   (if (not (tree? tree)) '()
-      (context:collect tree:model? tree)))
+      (context:collect tree tree:model?)))
 
 (define (tree:collect o predicate)
   (if (not (tree? o)) '()
       (if (predicate o) (cons o (append-map (cute tree:collect <> predicate) o))
           (append-map (cute tree:collect <> predicate) o))))
 
-(define (tree:collect o predicate)
-  (if (predicate o) (cons o (append-map (cute tree:collect <> predicate) o))
+(define (tree:filter o predicate)
+  (if (predicate o) (cons o (append-map (cute tree:filter <> predicate) o))
       '()))
 
-(define* (context:collect predicate tree #:optional (context '()))
-  (if (not (tree? tree)) '()
-      (let* ((context (tree->context tree context))
-             (rest (append-map (cute context:collect predicate <> context) tree)))
-        (if (not (predicate tree)) rest
-            (cons context rest)))))
-
 (define (tree:direction o)
   (match o
     ((? (is? 'event)) (tree:direction (.direction o)))
@@ -1057,15 +1059,46 @@ procedure)."
        `(,type ,@slots)))
     (_ o)))
 
+(define (tree:flatten-imports-definitions o)
+  (match o
+    (('root elements ...)
+     `(root ,@(append-map tree:flatten-imports-definitions elements)))
+    (('imports imports ...)
+     (filter (compose not (cute eq? 'location <>) car) imports))
+    (('definitions definitions ...)
+     (filter (compose not (cute eq? 'location <>) car) definitions))
+    (_ (list o))))
+
+(define (tree:scoped-name->compound-name o)
+  (match o
+    (('scoped-name name location ...)
+     `(compound-name (name ,name ,@location) ,@location))
+    (((and type (or 'root 'namespace 'namespace-root)) slots ...)
+     (let ((slots (map tree:scoped-name->compound-name slots)))
+       `(,type ,@slots)))
+    (((and type (or 'types-and-events 'behavior
+                    'behavior-compound 'behavior-statements)) slots ...)
+     (let ((slots (map tree:scoped-name->compound-name slots)))
+       `(,type ,@slots)))
+    ((and (type slots ...) (or (? tree:model?) (? tree:type?)))
+     (let ((slots (map tree:scoped-name->compound-name slots)))
+       `(,type ,@slots)))
+    (_ o)))
+
+(define (tree:normalize o)
+  ((compose tree:scoped-name->compound-name
+            tree:flatten-imports-definitions)
+   o))
+
 
 ;;;
 ;;; Context accessors.
 ;;;
 
-(define* (context:collect predicate tree #:optional (context '()))
+(define* (context:collect tree predicate #:optional (context '()))
   (if (not (tree? tree)) '()
       (let* ((context (tree->context tree context))
-             (rest (append-map (cute context:collect predicate <> context) tree)))
+             (rest (append-map (cute context:collect <> predicate context) tree)))
         (if (not (predicate tree)) rest
             (cons context rest)))))
 
