@@ -1,8 +1,9 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
 ;;; Copyright © 2012, 2013, 2014, 2015, 2016, 2017 Ludovic Courtès <ludo@gnu.org>
-;;; Copyright © 2017, 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2017, 2019, 2020, 2021, 2022, 2024, 2025 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2015 Mark H Weaver <mhw@netris.org>
+;;; Copyright © 2022, 2024 Rutger (regtur) van Beusekom <rutger@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -22,15 +23,20 @@
 (define-module (dzn shell-util)
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
+
   #:use-module (ice-9 ftw)
   #:use-module (ice-9 match)
+  #:use-module (ice-9 poe)
   #:use-module (ice-9 rdelim)
   #:use-module (ice-9 regex)
+
   #:export (block-format
+            canonicalize-file
             copy-recursively
             delete-file-recursively
             directory-exists?
-            file-is-directory?
+            dzn-file?
+            file-name->dzn-files
             find-files
             list-directory
             list-files
@@ -39,7 +45,8 @@
             set-file-time
             substitute
             substitute*
-            with-directory-excursion))
+            with-directory-excursion)
+  #:replace (file-is-directory?))
 
 (define (mingw?)
   (string-suffix? "mingw32" %host-type))
@@ -250,6 +257,14 @@ also be included.  If FAIL-ON-ERROR? is true, raise an exception upon error."
                             stat)
           string<?)))
 
+(define (canonicalize-file-unmemoized file-name-symbol)
+  (canonicalize-path (symbol->string file-name-symbol)))
+
+(define (canonicalize-file file-name)
+  (if (or (equal? file-name "-" ) (not file-name)) "-"
+      ((pure-funcq canonicalize-file-unmemoized)
+       (string->symbol file-name))))
+
 
 ;;;
 ;;; Text substitution (aka. sed).
@@ -397,3 +412,14 @@ match the terminating newline of a line."
                  (cons (string-append prologue indent)
                        tab-len))
                words))))
+
+
+;;;
+;;; Dezyne.
+;;;
+(define (dzn-file? file-name)
+  (string-suffix? ".dzn" file-name))
+
+(define (file-name->dzn-files file-name)
+  (if (not (file-is-directory? file-name)) (list file-name)
+      (list-files file-name dzn-file?)))
