@@ -1,6 +1,6 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2021 Rutger van Beusekom <rutger@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
@@ -23,18 +23,16 @@
 ;;; Code:
 
 (define-module (dzn vm ast)
-  #:use-module ((oop goops) #:renamer (lambda (x) (if (member x '(<port> <foreign>)) (symbol-append 'goops: x) x)))
-  #:use-module (dzn goops)
-  #:use-module (dzn vm goops)
+  #:use-module (dzn ast ast)
+  #:use-module (dzn ast lookup)
   #:use-module (dzn ast)
+  #:use-module (dzn vm goops)
   #:use-module (dzn vm runtime)
   #:export (ast:acceptance*
             ast:label*
             ast:statement
-            ast:trigger-equal?
-            ast:valued?)
+            ast:trigger-equal?)
   #:re-export (.port
-               ast:async?
                ast:external?
                ast:equal?
                ast:provides?
@@ -66,23 +64,6 @@
   (and (equal? (.port.name a) (.port.name b))
        (equal? (.event.name a) (.event.name b))))
 
-(define-method (ast:valued? (o <trigger>))
-  (ast:valued-in-triggers))
-
-(define-method (ast:async? (o <port>))
-  (let ((type (.type o)))
-    (and type
-         (string-prefix? "dzn.async" (string-join (ast:full-name type) ".")))))
-
-(define-method (ast:async? (o <action>))
-  (and=> (.port o) ast:async?))
-
-(define-method (ast:async? (o <trigger>))
-  (and=> (.port o) ast:async?))
-
-(define-method (ast:async? (o <runtime:port>))
-  (ast:async? (.ast o)))
-
 (define-method (ast:blocking? (o <runtime:port>))
   (ast:blocking? (.ast o)))
 
