@@ -1,6 +1,6 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2018, 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2018, 2019, 2020, 2021, 2022, 2023, 2024, 2025 Janneke Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2018, 2019 Rob Wieringa <rma.wieringa@gmail.com>
 ;;; Copyright © 2020, 2021, 2022, 2023 Rutger van Beusekom <rutger@dezyne.org>
 ;;;
@@ -31,7 +31,7 @@
   #:use-module (ice-9 match)
   #:use-module (ice-9 rdelim)
 
-  #:use-module (dzn ast goops)
+  #:use-module (dzn ast ast)
   #:use-module (dzn ast)
   #:use-module (dzn code language dzn)
   #:use-module (dzn misc)
@@ -131,7 +131,7 @@
 (define-method (pc-event? (pc <program-counter>) (o <defer-qout>))
   #t)
 
-(define-method (pc-event? (pc <program-counter>) (o <initial-compound>))
+(define-method (pc-event? (pc <program-counter>) (o <on>))
   (pc-event? (.instance pc) (.trigger pc)))
 
 (define-method (pc-event? (o <runtime:port>) (trigger <trigger>))
@@ -231,16 +231,16 @@
 (define-method (pc->event (pc <program-counter>) (o <statement>))
   (pc->event (.instance pc) o))
 
-(define-method (pc->event (pc <program-counter>) (o <initial-compound>))
+(define-method (pc->event (pc <program-counter>) (o <on>))
   (pc->event (.instance pc) o (.trigger pc)))
 
-(define-method (pc->event (o <runtime:port>) (compound <initial-compound>) (trigger <trigger>))
+(define-method (pc->event (o <runtime:port>) (on <on>) (trigger <trigger>))
   (cons trigger
         (if (is-a? (%sut) <runtime:port>)
             (format #f "~a" (.event.name trigger))
             (format #f "~a.~a" (trace-name o) (.event.name trigger)))))
 
-(define-method (pc->event (o <runtime:component>) (compound <initial-compound>) (trigger <trigger>))
+(define-method (pc->event (o <runtime:component>) (on <on>) (trigger <trigger>))
   (cons trigger
         (let* ((port (.port trigger))
                (r:other-port (runtime:other-port (runtime:port o port))))
@@ -284,7 +284,7 @@
     (cons q-out (trigger->string trigger))))
 
 (define-method (pc->event (pc <program-counter>) (o <trigger-return>))
-  (pc->event (.instance pc) (clone o #:event.name (format #f "~a" (.event.name o)))))
+  (pc->event (.instance pc) o))
 
 (define-method (pc->event (o <runtime:port>) (return <trigger-return>))
   (cons return
@@ -316,16 +316,16 @@
 (define-method (pc->component-event (pc <program-counter>) (o <statement>))
   (pc->component-event (.instance pc) o))
 
-(define-method (pc->component-event (pc <program-counter>) (o <initial-compound>))
+(define-method (pc->component-event (pc <program-counter>) (o <on>))
   (pc->component-event (.instance pc) o (.trigger pc)))
 
-(define-method (pc->component-event (o <runtime:port>) (compound <initial-compound>) (trigger <trigger>))
+(define-method (pc->component-event (o <runtime:port>) (on <on>) (trigger <trigger>))
   (cons trigger
         (if (is-a? (%sut) <runtime:port>)
             (format #f "~a" (.event.name trigger))
             (format #f "~a.~a" (.name (.ast o)) (.event.name trigger)))))
 
-(define-method (pc->component-event (o <runtime:component>) (compound <initial-compound>) (trigger <trigger>))
+(define-method (pc->component-event (o <runtime:component>) (on <on>) (trigger <trigger>))
   (cons trigger
         (let* ((port (.port trigger))
                (r:port (runtime:port o port)))
@@ -342,7 +342,7 @@
             (format #f "~a.~a" (trace-name r:port) (.event.name action)))))))
 
 (define-method (pc->component-event (pc <program-counter>) (o <trigger-return>))
-  (pc->component-event (.instance pc) (clone o #:event.name (format #f "~a" (.event.name o)))))
+  (pc->component-event (.instance pc) o))
 
 (define-method (pc->component-event (o <runtime:component>) (return <trigger-return>))
   (cons return
@@ -380,7 +380,7 @@
 (define-method (pc-arrow? (pc <program-counter>) (o <statement>))
   (pc-arrow? (.instance pc) o))
 
-(define-method (pc-arrow? (pc <program-counter>) (o <initial-compound>))
+(define-method (pc-arrow? (pc <program-counter>) (o <on>))
   (pc-arrow? (.instance pc) (.trigger pc)))
 
 (define-method (pc-arrow? (o <runtime:port>) (trigger <trigger>))
@@ -440,10 +440,10 @@
 (define-method (pc->arrow (pc <program-counter>) (o <statement>))
   (pc->arrow (.instance pc) o))
 
-(define-method (pc->arrow (pc <program-counter>) (o <initial-compound>))
+(define-method (pc->arrow (pc <program-counter>) (o <on>))
   (pc->arrow (.instance pc) o (.trigger pc)))
 
-(define-method (pc->arrow (o <runtime:port>) (compound <initial-compound>) (trigger <trigger>))
+(define-method (pc->arrow (o <runtime:port>) (on <on>) (trigger <trigger>))
   (cons trigger
         (if (or (ast:provides? o)
                 (and (is-a? (%sut) <runtime:port>)
@@ -451,7 +451,7 @@
             (format #f "~a.~a -> ..." (runtime:instance->string o) (.event.name trigger))
             (format #f "... -> ~a.~a" (runtime:instance->string o) (.event.name trigger)))))
 
-(define-method (pc->arrow (o <runtime:port>) (compound <initial-compound>) (trigger <synth-trigger>))
+(define-method (pc->arrow (o <runtime:port>) (on <on>) (trigger <synth-trigger>))
   (cons trigger
         (if (or (ast:provides? o)
                 (and (is-a? (%sut) <runtime:port>)
@@ -459,7 +459,7 @@
             (format #f "... <- ~a.~a" (runtime:instance->string o) (.event.name trigger))
             (format #f "~a.~a <- ..." (runtime:instance->string o) (.event.name trigger)))))
 
-(define-method (pc->arrow (o <runtime:component>) (compound <initial-compound>) (trigger <trigger>))
+(define-method (pc->arrow (o <runtime:component>) (on <on>) (trigger <trigger>))
   (cons trigger
         (let* ((port (.port trigger))
                (r:port (runtime:port o port))
@@ -520,7 +520,7 @@
           (format #f "~a.~a <- ..." (runtime:instance->string r:port) (.event.name trigger)))))
 
 (define-method (pc->arrow (pc <program-counter>) (o <trigger-return>))
-  (pc->arrow (.instance pc) (clone o #:event.name (format #f "~a" (.event.name o)))))
+  (pc->arrow (.instance pc) o))
 
 (define-method (pc->arrow (o <runtime:port>) (return <trigger-return>))
   (cons return
@@ -573,7 +573,7 @@
   (if (and=> (.status o) (negate (is? <end-of-trail>))) (pc-event? o)
       (pc-step? o (.statement o))))
 
-(define-method (pc-step? (pc <program-counter>) (o <initial-compound>))
+(define-method (pc-step? (pc <program-counter>) (o <on>))
   (pc-arrow? (.instance pc) (.trigger pc)))
 
 (define-method (pc-step? (pc <program-counter>) (o <statement>))
@@ -662,14 +662,14 @@ Add (synthesize) missing PCs for <q-in>, <q-out> and <trigger-return>."
                    (trigger (.trigger pc))
                    (trigger (make <synth-trigger> #:event.name (.event.name trigger)))
                    (trigger (clone trigger #:parent interface))
-                   (initial-compound (make <initial-compound>))
+                   (initial-compound (make <on>))
                    (initial-compound (clone initial-compound #:parent interface))
                    (trigger-pc (clone pc
                                       #:trigger trigger
                                       #:statement initial-compound)))
               (loop (cdr trace) (cons* trigger-pc pc result))))
            ((and (is-a? (%sut) <runtime:port>)
-                 (is-a? statement <initial-compound>))
+                 (is-a? statement <on>))
             (let ((client-pc (clone pc #:instance (car (%instances)))))
               (loop (cdr trace) (cons* client-pc pc result))))
            ((and (is-a? (%sut) <runtime:port>)
@@ -822,8 +822,20 @@ the location of the executed <on>-statement."
                (pc (if (not trigger) pc (clone pc #:trigger trigger))))
           (cons pc (loop (cdr trace)))))))
 
-(define (location-prefix o)
-  (format #f "~a: " (or (and=> o ast:location->string) "<unknown-file>")))
+(define-method (location-prefix (o <string>))
+  (format #f "~a: " o))
+
+(define-method (location-prefix (o <boolean>))
+  (location-prefix "<unknown-file>:0:0"))
+
+(define-method (location-prefix (o <ast>))
+  (location-prefix (ast:location->string o)))
+
+(define-method (location-prefix (o <interface>))
+  (location-prefix (ast:statement o)))
+
+(define-method (location-prefix (o <component>))
+  (location-prefix (ast:statement o)))
 
 (define* (display-trace trace #:key locations? state? verbose?)
   "Write TRACE as split-arrows trace to stdout.  When LOCATIONS?,
@@ -833,7 +845,8 @@ intermediate steps such as assignments, function calls, replies,
   (let* ((trace (complete-split-arrows-pcs trace))
          (trace (reverse (set-trigger-locations (reverse trace))))
          (steps (if verbose? (trace->steps trace)
-                    (trace->arrows trace))))
+                    (trace->arrows trace)))
+         (max (length steps)))
     (define write-step
       (match-lambda*
         (((pc ast . string) i)
@@ -844,10 +857,19 @@ intermediate steps such as assignments, function calls, replies,
          (write-line string)
          (when (and state?
                     (odd? i)
-                    (< i (1- (length steps))))
+                    (< i (- max 2)))
            (serialize (.state pc) (current-output-port))
            (newline)))))
-    (for-each write-step steps (iota (length steps)))))
+    (define (arrow? string)
+      (or (string-contains string "<-")
+          (string-contains string "->")))
+    (let loop ((steps steps) (i 0))
+      (match steps
+        (() #t)
+        (((and step (pc ast . string)) steps ...)
+         (write-step step i)
+         (let ((i (if (arrow? string) (1+ i) i)))
+           (loop steps i)))))))
 
 (define (initial-error-message traces)
   (let* ((pcs (map car traces))
@@ -1094,7 +1116,9 @@ value of the trail."
       (serialize (.state pc) (current-output-port))
       (newline))
 
-    (when (and (equal? trace-format "trace") initial-message)
+    (when (and (equal? trace-format "trace")
+               initial-message
+               (not (is-a? status <invariant-error>)))
       (display initial-message))
     (when (pair? traces)
       (let ((final-messages (final-error-messages traces)))
